ResponseBuilder

Struct ResponseBuilder 

pub struct ResponseBuilder { /* private fields */ }
A response builder with pre-allocated buffer for efficient response creation.

This builder allocates a buffer upfront and allows building the response body incrementally without reallocations.

Example

use armature_core::response_buffer::ResponseBuilder;

let response = ResponseBuilder::new()
    .status(200)
    .header("Content-Type", "application/json")
    .body_json(&data)?
    .build();

Implementations

Source

impl ResponseBuilder

pub fn new() -> Self

Create a new builder with default buffer capacity.

pub fn with_capacity(capacity: usize) -> Self

Create with custom buffer capacity.

pub fn status(self, status: u16) -> Self

Set status code.

pub fn header(self, name: impl Into<String>, value: impl Into<String>) -> Self

Add a header.

pub fn content_type(self, value: impl Into<String>) -> Self

Set Content-Type header.

pub fn body(self, data: &[u8]) -> Self

Set body from bytes.

pub fn body_str(self, s: &str) -> Self

Set body from string.

pub fn body_json<T: Serialize>(self, value: &T) -> Result<Self, Error>

Set body from JSON.

pub fn body_mut(&mut self) -> &mut ResponseBuffer

Get mutable reference to body buffer for direct writes.

pub fn build(self) -> HttpResponse

Build the final HttpResponse.