WorkerState

Struct WorkerState 

pub struct WorkerState<T: 'static> { /* private fields */ }
Per-worker state storage.

This provides thread-local storage for arbitrary state that needs to be accessed on the hot path without Arc cloning overhead.

Use Cases

  • Database connection pools (one per worker)
  • Caches (per-worker to avoid contention)
  • Metrics collectors
  • Random number generators
  • Pre-allocated buffers

Example

use armature_core::worker::{WorkerState, init_worker_state};

// Define state
struct MyState {
    counter: u64,
    buffer: Vec<u8>,
}

// Initialize once per worker
init_worker_state(MyState {
    counter: 0,
    buffer: Vec::with_capacity(4096),
});

// Access without Arc cloning
WorkerState::<MyState>::with_mut(|state| {
    state.counter += 1;
});

Implementations

Source

impl<T: 'static + Send> WorkerState<T>

pub fn init(value: T)

Initialize state for this worker.

Call once per worker thread during startup.

pub fn with<F, R>(f: F) -> R
where F: FnOnce(&T) -> R,

Access state immutably.

Panics

Panics if state was not initialized. Use try_with for non-panicking.

pub fn with_mut<F, R>(f: F) -> R
where F: FnOnce(&mut T) -> R,

Access state mutably.

Panics

Panics if state was not initialized.

pub fn try_with<F, R>(f: F) -> Option<R>
where F: FnOnce(&T) -> R,

Try to access state immutably.

Returns None if state was not initialized.

pub fn try_with_mut<F, R>(f: F) -> Option<R>
where F: FnOnce(&mut T) -> R,

Try to access state mutably.

Returns None if state was not initialized.

pub fn is_initialized() -> bool

Check if state is initialized.

pub fn take() -> Option<T>

Remove state and return it.

pub fn replace(value: T) -> Option<T>

Replace state with a new value, returning the old one.