pub struct BoxedHandler { /* private fields */ }Expand description
Type-erased handler for storing in collections.
While Handler uses associated types for zero-cost abstraction,
we need type erasure to store different handlers in the same Vec.
This type performs the erasure while keeping the actual handler call as optimized as possible via vtable dispatch with inlined inner handlers.
Implementations
Sourceimpl BoxedHandler
impl BoxedHandler
Sourcepub fn new<H: Handler>(handler: H) -> Self
pub fn new<H: Handler>(handler: H) -> Self
Create a new boxed handler from any Handler.
The handler is wrapped in an Arc for cheap cloning.
Sourcepub fn call(
&self,
req: HttpRequest,
) -> Pin<Box<dyn Future<Output = Result<HttpResponse, Error>> + Send>>
pub fn call( &self, req: HttpRequest, ) -> Pin<Box<dyn Future<Output = Result<HttpResponse, Error>> + Send>>
Call the handler.
This goes through a vtable but the actual handler implementation is monomorphized and can be inlined within the wrapper.